@@ -1,4 +1,4 @@
-# Copyright (C) 2004-2011 by Barry A. Warsaw
+# Copyright (C) 2004-2012 by Barry A. Warsaw
 #
 # This file is part of flufl.enum
 #
@@ -16,17 +16,17 @@
 
 """Package init."""
 
-from __future__ import absolute_import, unicode_literals
+from __future__ import absolute_import, print_function, unicode_literals
 
 __metaclass__ = type
 __all__ = [
-    b'Enum',
-    b'__version__',
-    b'make_enum',
+    'Enum',
+    '__version__',
+    'make_enum',
     ]
 
 
-__version__ = '3.2'
+__version__ = '3.3'
 
 
-from ._enum import Enum, make_enum
+from ._enum import Enum, make, make_enum
